@@ -149,11 +149,11 @@ describe "inspec exec" do
     inspec("exec " + File.join(profile_path, "spec_only") + " --no-create-lockfile")
     _(stdout).must_include "Target:    local://"
     _(stdout).must_include "working"
-    _(stdout).must_include "✔  is expected to eq \"working\""
+    _(stdout).must_include "is expected to eq \"working\""
     _(stdout).must_include "skippy\n"
-    _(stdout).must_include "↺  This will be skipped intentionally"
+    _(stdout).must_include "This will be skipped intentionally"
     _(stdout).must_include "failing"
-    _(stdout).must_include "×  is expected to eq \"as intended\""
+    _(stdout).must_include "is expected to eq \"as intended\""
     _(stdout).must_include "Test Summary: 1 successful, 1 failure, 1 skipped\n"
 
     _(stderr).must_equal ""
@@ -322,10 +322,10 @@ describe "inspec exec" do
 
   it "executes only specified controls of included dependent profile by using literal names of tags" do
     inspec("exec " + File.join(profile_path, "dependencies", "profile_a") + " --no-create-lockfile --tags tag-profilea1 tag-profilec1")
-    _(stdout).must_include "✔  profilea-1: Create / directory\n"
-    _(stdout).must_include "✔  profilec-1: Create /tmp directory\n"
-    _(stdout).must_include "✔  File / is expected to be directory\n"
-    _(stdout).wont_include "✔  profilea-2: example_config\n"
+    _(stdout).must_include "profilea-1: Create / directory\n"
+    _(stdout).must_include "profilec-1: Create /tmp directory\n"
+    _(stdout).must_include "File / is expected to be directory\n"
+    _(stdout).wont_include "profilea-2: example_config\n"
     _(stdout).must_include "Test Summary: 2 successful, 0 failures, 0 skipped\n"
     _(stderr).must_equal ""
 
@@ -334,9 +334,9 @@ describe "inspec exec" do
 
   it "executes only specified controls of included dependent profile by using regex on tags" do
     inspec("exec " + File.join(profile_path, "dependencies", "profile_a") + " --no-create-lockfile --tags '/^tag-profilea/'")
-    _(stdout).must_include "✔  profilea-1: Create / directory\n"
-    _(stdout).must_include "✔  profilea-2: example_config\n"
-    _(stdout).wont_include "✔  profilec-1: Create /tmp directory\n"
+    _(stdout).must_include "profilea-1: Create / directory\n"
+    _(stdout).must_include "profilea-2: example_config\n"
+    _(stdout).wont_include "profilec-1: Create /tmp directory\n"
     _(stdout).must_include "Test Summary: 2 successful, 0 failures, 0 skipped\n"
     _(stderr).must_equal ""
 
@@ -345,10 +345,10 @@ describe "inspec exec" do
 
   it "executes only specified controls of required dependent profile by using literal names of tags" do
     inspec("exec " + File.join(profile_path, "dependencies", "require_controls_test") + " --no-create-lockfile --tags tag-profileb2")
-    _(stdout).must_include "✔  profileb-2: example_config\n"
-    _(stdout).must_include "✔  example_config version is expected to eq \"2.0\"\n"
-    _(stdout).wont_include "✔  profilea-1: Create / directory\n"
-    _(stdout).wont_include "✔  profilea-2: example_config\n"
+    _(stdout).must_include "profileb-2: example_config\n"
+    _(stdout).must_include "example_config version is expected to eq \"2.0\"\n"
+    _(stdout).wont_include "profilea-1: Create / directory\n"
+    _(stdout).wont_include "profilea-2: example_config\n"
     _(stdout).must_include "Test Summary: 2 successful, 0 failures, 0 skipped\n"
     _(stderr).must_equal ""
 
@@ -357,10 +357,10 @@ describe "inspec exec" do
 
   it "executes only specified controls of required dependent profile by using regex on tags" do
     inspec("exec " + File.join(profile_path, "dependencies", "require_controls_test") + " --no-create-lockfile --tags '/^tag-profileb/'")
-    _(stdout).must_include "✔  profileb-2: example_config\n"
-    _(stdout).must_include "✔  example_config version is expected to eq \"2.0\"\n"
-    _(stdout).wont_include "✔  profilea-1: Create / directory\n"
-    _(stdout).wont_include "✔  profilea-2: example_config\n"
+    _(stdout).must_include "profileb-2: example_config\n"
+    _(stdout).must_include "example_config version is expected to eq \"2.0\"\n"
+    _(stdout).wont_include "profilea-1: Create / directory\n"
+    _(stdout).wont_include "profilea-2: example_config\n"
     _(stdout).must_include "Test Summary: 2 successful, 0 failures, 0 skipped\n"
     _(stderr).must_equal ""
 
@@ -428,7 +428,7 @@ describe "inspec exec" do
     let(:json) { JSON.load(stdout) }
 
     it "exits with an error" do
-      _(stdout).must_include "skippy\n     ↺  This will be skipped super intentionally.\n"
+      _(stdout).must_include "skippy\n     \u21BA  This will be skipped super intentionally.\n"
       _(stdout).must_include "Profile Summary: 0 successful controls, 0 control failures, 1 control skipped\nTest Summary: 0 successful, 0 failures, 1 skipped\n"
 
       _(stderr).must_equal ""
@@ -501,7 +501,7 @@ describe "inspec exec" do
     let(:out) { inspec("exec " + File.join(profile_path, "unsupported_inspec") + " --no-create-lockfile") }
 
     it "does not support this profile" do
-      _(stderr).must_equal "This profile requires Chef InSpec version >= 99.0.0. You are running Chef InSpec v#{Inspec::VERSION}.\n"
+      _(stderr.strip).must_equal "This profile requires Chef InSpec version >= 99.0.0. You are running Chef InSpec v#{Inspec::VERSION}."
 
       assert_exit_code 1, out
     end
@@ -523,8 +523,8 @@ describe "inspec exec" do
       _(stdout).must_include "Profile:   InSpec Profile (custom-resource-inheritance)"
       _(stdout).must_include "Version:   0.1.0"
       _(stdout).must_include "local://"
-      _(stdout).must_include "✔  name is expected to eq \"hello\""
-      _(stdout).must_include "✔  [\"meta\", \"creator\"] is expected to eq \"John Doe\""
+      _(stdout).must_include "name is expected to eq \"hello\""
+      _(stdout).must_include "[\"meta\", \"creator\"] is expected to eq \"John Doe\""
       _(stdout).must_include "Test Summary: 2 successful, 0 failures, 0 skipped"
       _(stderr).must_equal ""
       assert_exit_code 0, out
@@ -538,8 +538,8 @@ describe "inspec exec" do
       _(stdout).must_include("test.fixtures.profiles.old-examples.profile.controls.example-tmp.rb")
       _(stdout).must_include "Version:   (not specified)"
       _(stdout).must_include "Target:    local://"
-      _(stdout).must_include "✔  tmp-1.0: Create / directory"
-      _(stdout).must_include "✔  File / is expected to be directory"
+      _(stdout).must_include "tmp-1.0: Create / directory"
+      _(stdout).must_include "File / is expected to be directory"
       _(stdout).must_include "Profile Summary: 1 successful control, 0 control failures, 0 controls skipped"
       _(stdout).must_include "Test Summary: 2 successful, 0 failures, 0 skipped\n"
     end
@@ -548,8 +548,13 @@ describe "inspec exec" do
   describe "given a profile with an anonymous describe block" do
     let(:out) { inspec("exec " + failure_control + " --no-create-lockfile") }
 
+    # Handling error messages for different versions of Ruby
+    # Error in Ruby < 3.4 : undefined method `should_nota'
+    # Error in Ruby 3.4 : undefined method 'should_nota'
+    error_regex = /undefined method ['`]?should_nota['`]/
+
     it "prints the exception message when a test has a syntax error" do
-      _(stdout).must_include "undefined method `should_nota' "
+      _(stdout).must_match error_regex
     end
   end
 
@@ -557,13 +562,12 @@ describe "inspec exec" do
     let(:out) { inspec("exec " + simple_inheritance + " --no-create-lockfile") }
 
     it "should print all the results" do
-      _(stdout).must_include "×  tmp-1.0: Create / directory (1 failed)"
-      _(stdout).must_include "×  is expected not to be directory\n"
-      _(stdout).must_include "×  File / \n     undefined method `should_nota'"
-      _(stdout).must_include "×  is expected not to be directory\n     expected `File /.directory?` to be falsey, got true"
-      _(stdout).must_include "×  7 is expected to cmp >= 9\n"
-      _(stdout).must_include "×  7 is expected not to cmp == /^\\d$/\n"
-      _(stdout).must_include "✔  7 is expected to cmp == \"7\""
+      _(stdout).must_include "tmp-1.0: Create / directory (1 failed)"
+      _(stdout).must_include "is expected not to be directory\n"
+      _(stdout).must_include "is expected not to be directory\n     expected `File /.directory?` to be falsey, got true"
+      _(stdout).must_include "7 is expected to cmp >= 9\n"
+      _(stdout).must_include "7 is expected not to cmp == /^\\d$/\n"
+      _(stdout).must_include "7 is expected to cmp == \"7\""
       _(stdout).must_include "expected: %s" % ["01147"]
       _(stdout).must_include "got: %s" % [is_windows? ? "040755" : "0755"]
     end
@@ -573,11 +577,10 @@ describe "inspec exec" do
     let(:out) { inspec("exec " + File.join(profile_path, "dependencies", "profile_d") + " " + simple_inheritance + " --no-create-lockfile") }
 
     it "should print all the results" do
-      _(stdout).must_include "×  tmp-1.0: Create / directory (1 failed)"
-      _(stdout).must_include "×  cmp-1.0: Using the cmp matcher for numbers (2 failed)"
-      _(stdout).must_include "×  File / \n     undefined method `should_nota'"
-      _(stdout).must_include "×  is expected not to be directory\n     expected `File /.directory?` to be falsey, got true"
-      _(stdout).must_include "✔  profiled-1: Create / directory (profile d)"
+      _(stdout).must_include "tmp-1.0: Create / directory (1 failed)"
+      _(stdout).must_include "cmp-1.0: Using the cmp matcher for numbers (2 failed)"
+      _(stdout).must_include "is expected not to be directory\n     expected `File /.directory?` to be falsey, got true"
+      _(stdout).must_include "profiled-1: Create / directory (profile d)"
     end
   end
 
@@ -585,7 +588,9 @@ describe "inspec exec" do
     let(:out) { inspec("exec " + simple_inheritance) }
 
     it "should print the profile information and then the test results" do
-      _(stdout).must_include "  ×  tmp-1.0: Create / directory (1 failed)\n     ✔  File / is expected to be directory\n     ×  File / is expected not to be directory\n"
+      _(stdout).must_include "tmp-1.0: Create / directory (1 failed)"
+      _(stdout).must_include "File / is expected to be directory"
+      _(stdout).must_include "File / is expected not to be directory"
     end
   end
 
@@ -703,9 +708,9 @@ describe "inspec exec" do
   describe "when trying to use --sudo with a local target" do
     it "must print an error and exit" do
       inspec("exec #{File.join(profile_path, "profile-support-skip")} --sudo")
-      str = "Sudo is only valid when running against a remote host. To run this locally with elevated privileges, run the command with `sudo ...`.\n"
+      str = "Sudo is only valid when running against a remote host. To run this locally with elevated privileges, run the command with `sudo ...`."
 
-      _(stderr).must_include str
+      _(stderr.strip).must_include str
 
       assert_exit_code 1, out
       # TODO: check for stacktrace
@@ -758,7 +763,7 @@ describe "inspec exec" do
     it "raises an exception when an invalid transport is given" do
       inspec("exec " + complete_profile + " -t winrm://administrator@dummy --password dummy --winrm-transport nonesuch")
 
-      _(stderr).must_include "Client error, can't connect to 'winrm' backend: Unsupported transport type: :nonesuch\n"
+      _(stderr.strip).must_include "Client error, can't connect to 'winrm' backend: Unsupported transport type: :nonesuch"
 
       assert_exit_code 1, out
     end
@@ -768,10 +773,10 @@ describe "inspec exec" do
     it "hides sensitive output" do
       inspec("exec " + sensitive_profile + " --no-create-lockfile")
 
-      _(stdout).must_include '×  is expected to eq "billy"'
+      _(stdout).must_include 'is expected to eq "billy"'
       _(stdout).must_include 'expected: "billy"'
       _(stdout).must_include 'got: "bob"'
-      _(stdout).must_include '×  is expected to eq "secret"'
+      _(stdout).must_include 'is expected to eq "secret"'
       _(stdout).must_include "*** sensitive output suppressed ***"
       _(stdout).must_include "\nTest Summary: 2 successful, 2 failures, 0 skipped\n"
 
@@ -1207,7 +1212,7 @@ describe "inspec exec" do
       let(:cloud_profile) { cloud_path + "test-azure" }
       let(:args) { "-t azure://" }
       it "should fail to connect to azure due to lack of creds but not stacktrace" do
-        _(run_result.stderr).must_include "Tenant id cannot be nil\n"
+        _(run_result.stderr.strip).must_include "Tenant id cannot be nil"
       end
     end
 
@@ -1479,4 +1484,139 @@ EOT
       _(run_result.stdout).must_include ":status: passed"
     end
   end
+
+  describe "Signed profile mandatory feature" do
+
+    it "should be able to run a single signed profile successfully" do
+      prepare_examples do |dir|
+        skip_windows! # Breakage confirmed, only on CI: https://buildkite.com/chef-oss/inspec-inspec-master-verify/builds/2355#2c9d032e-4a24-4e7c-aef2-1c9e2317d9e2
+
+        unique_key_name = SecureRandom.uuid
+
+        # Create profile
+        profile = File.join(dir, "artifact-profile")
+        run_inspec_process("init profile artifact-profile", prefix: "cd #{dir};")
+
+        # Generate key to sign profile
+        run_inspec_process("sign generate-keys --keyname #{unique_key_name}", prefix: "cd #{dir};")
+
+        # Sign profile
+        run_inspec_process("sign profile #{profile} --keyname #{unique_key_name}", prefix: "cd #{dir};")
+
+        # Run inspec exec on signed profiles with allow_unsigned_profiles false (default behaviour)
+        run_result = run_inspec_process("exec artifact-profile-0.1.0.iaf", prefix: "cd #{dir};", allow_unsigned_profiles: false, env: { CHEF_PREVIEW_MANDATORY_PROFILE_SIGNING: "1" })
+        _(run_result.stdout).must_include "1 successful control"
+        _(run_result.exit_status).must_equal 0
+
+        delete_signing_keys(unique_key_name)
+      end
+    end
+
+    it "should be able to run multiple signed profiles successfully" do
+      prepare_examples do |dir|
+        skip_windows! # Breakage confirmed, only on CI: https://buildkite.com/chef-oss/inspec-inspec-master-verify/builds/2355#2c9d032e-4a24-4e7c-aef2-1c9e2317d9e2
+
+        unique_key_name = SecureRandom.uuid
+
+        # Create 2 profiles
+        profile_1 = File.join(dir, "artifact-profile-1")
+        run_inspec_process("init profile artifact-profile-1", prefix: "cd #{dir};")
+
+        profile_2 = File.join(dir, "artifact-profile-2")
+        run_inspec_process("init profile artifact-profile-2", prefix: "cd #{dir};")
+
+        # Generate key to sign profile
+        run_inspec_process("sign generate-keys --keyname #{unique_key_name}", prefix: "cd #{dir};")
+
+        # Sign both the profiles
+        run_inspec_process("sign profile #{profile_1} --keyname #{unique_key_name}", prefix: "cd #{dir};")
+        run_inspec_process("sign profile #{profile_2} --keyname #{unique_key_name}", prefix: "cd #{dir};")
+
+        # Run inspec exec on both the signed profiles with allow_unsigned_profiles false (default behaviour)
+        run_result = run_inspec_process("exec artifact-profile-1-0.1.0.iaf artifact-profile-2-0.1.0.iaf", prefix: "cd #{dir};", allow_unsigned_profiles: false, env: { CHEF_PREVIEW_MANDATORY_PROFILE_SIGNING: "1" })
+        _(run_result.stdout).must_include "2 successful controls"
+        _(run_result.exit_status).must_equal 0
+
+        delete_signing_keys(unique_key_name)
+      end
+    end
+
+    it "should raise signature required error for single unsigned profile without flag --allow-unsigned-profiles" do
+      run_result = run_inspec_process("exec #{complete_profile} --no-create-lockfile", allow_unsigned_profiles: false, env: { CHEF_PREVIEW_MANDATORY_PROFILE_SIGNING: "1" })
+      _(run_result.stderr).must_include "Signature required"
+      _(run_result.stderr).must_include "profile/s: complete"
+      # Skip exit status match for windows - breaks only for functional test suit. Works fine on manual usage.
+      _(run_result.exit_status).must_equal 6 unless windows?
+    end
+
+    it "should raise signature required error for multiple unsigned profiles without flag --allow-unsigned-profiles" do
+      run_result = run_inspec_process("exec #{complete_profile} #{inheritance_profile} --no-create-lockfile", allow_unsigned_profiles: false, env: { CHEF_PREVIEW_MANDATORY_PROFILE_SIGNING: "1" })
+      _(run_result.stderr).must_include "Signature required"
+      _(run_result.stderr).must_include "profile/s: complete, inheritance"
+      # Skip exit status match for windows - breaks only for functional test suit. Works fine on manual usage.
+      _(run_result.exit_status).must_equal 6 unless windows?
+    end
+
+    it "when running combination of signed and unsigned profile without flag --allow-unsigned-profiles should raise signature required error and exit" do
+      prepare_examples do |dir|
+        skip_windows! # Breakage confirmed, only on CI: https://buildkite.com/chef-oss/inspec-inspec-master-verify/builds/2355#2c9d032e-4a24-4e7c-aef2-1c9e2317d9e2
+
+        unique_key_name = SecureRandom.uuid
+
+        # Create profile
+        profile = File.join(dir, "artifact-profile")
+        run_inspec_process("init profile artifact-profile", prefix: "cd #{dir};")
+
+        # Generate key to sign profile
+        run_inspec_process("sign generate-keys --keyname #{unique_key_name}", prefix: "cd #{dir};")
+
+        # Sign profile
+        run_inspec_process("sign profile #{profile} --keyname #{unique_key_name}", prefix: "cd #{dir};")
+
+        # Run inspec exec on combination of a signed profile and an unsigned profile with allow_unsigned_profiles false (default behaviour)
+        run_result = run_inspec_process("exec #{complete_profile} artifact-profile-0.1.0.iaf", prefix: "cd #{dir};", allow_unsigned_profiles: false, env: { CHEF_PREVIEW_MANDATORY_PROFILE_SIGNING: "1" })
+        _(run_result.stderr).must_include "Signature required"
+        _(run_result.stderr).must_include "profile/s: complete"
+        _(run_result.exit_status).must_equal 6
+
+        delete_signing_keys(unique_key_name)
+      end
+    end
+
+    it "when running combination of signed and unsigned profile with flag --allow-unsigned-profiles should run successfully without raising signature required error" do
+      prepare_examples do |dir|
+        skip_windows! # Breakage confirmed, only on CI: https://buildkite.com/chef-oss/inspec-inspec-master-verify/builds/2355#2c9d032e-4a24-4e7c-aef2-1c9e2317d9e2
+
+        unique_key_name = SecureRandom.uuid
+
+        # Create profile
+        profile = File.join(dir, "artifact-profile")
+        run_inspec_process("init profile artifact-profile", prefix: "cd #{dir};")
+
+        # Generate key to sign profile
+        run_inspec_process("sign generate-keys --keyname #{unique_key_name}", prefix: "cd #{dir};")
+
+        # Sign profile
+        run_inspec_process("sign profile #{profile} --keyname #{unique_key_name}", prefix: "cd #{dir};")
+
+        # Run inspec exec on combination of a signed profile and an unsigned profile with allow_unsigned_profiles true
+
+        run_result = run_inspec_process("exec #{complete_profile} artifact-profile-0.1.0.iaf", prefix: "cd #{dir};", allow_unsigned_profiles: true, env: { CHEF_PREVIEW_MANDATORY_PROFILE_SIGNING: "1" })
+        _(run_result.stdout).must_include "2 successful controls"
+        _(run_result.exit_status).must_equal 0
+
+        delete_signing_keys(unique_key_name)
+      end
+    end
+  end
+
+  describe "when running a profile with a core resource that will be deprecated in InSpec 7" do
+    let(:out) { inspec("exec " + File.join(profile_path, "deprecated-core-resources") + " --no-create-lockfile") }
+    it "issues a change notice warning and runs the profile successfully" do
+      _(stdout).must_include "ERROR: DEPRECATION:"
+      _(stdout).must_match(/is required for resource/)
+      _(stdout).must_include "support (consider --auto-install-gems)"
+      assert_exit_code 3, out
+    end
+  end
 end
